var module_metadata_8c =
[
    [ "factory_data", "structfactory__data.html", "structfactory__data" ],
    [ "NAME", "module-metadata_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "PW_LOG_TOPIC_DEFAULT", "module-metadata_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
    [ "pipewire__module_init", "module-metadata_8c.html#a8a1bb60befc3b89c8c1f5417f777083f", null ],
    [ "pw_core_metadata_export", "module-metadata_8c.html#a228bd314acde265f020f512876da8fa8", null ],
    [ "PW_LOG_TOPIC_STATIC", "module-metadata_8c.html#aa0d958627aeb2fb6f2e897d656b5c0c6", null ],
    [ "pw_metadata_new", "module-metadata_8c.html#a50f93786e94ebab7a77bb9e025ef3c6c", null ],
    [ "pw_protocol_native_ext_metadata_init", "module-metadata_8c.html#a737733e0169d79fc44a61960c58f0fdc", null ]
];